@@ -13,12 +13,12 @@
 import logging
 import os
 from botocore import xform_name
-from botocore.docs.bcdoc.docevents import DOC_EVENTS
 from botocore.model import StringShape
 from botocore.utils import is_json_value_header
 
 from awscli import SCALAR_TYPES
 from awscli.argprocess import ParamShorthandDocGen
+from awscli.bcdoc.docevents import DOC_EVENTS
 from awscli.topictags import TopicTagDB
 from awscli.utils import find_service_and_method_in_event_name
 
